rule win_pocodown_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.pocodown."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.pocodown"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8b84248c000000 ffc8 898424a0010000 c784248800000000000000 ba01000000 488b8c24e0010000 }
            // n = 6, score = 200
            //   8b84248c000000       | mov                 dword ptr [esp + 0x1a0], eax
            //   ffc8                 | mov                 dword ptr [esp + 0x88], 0
            //   898424a0010000       | mov                 edx, 1
            //   c784248800000000000000     | mov    eax, dword ptr [esp + 0x8c]
            //   ba01000000           | dec                 eax
            //   488b8c24e0010000     | mov                 dword ptr [esp + 0x1a0], eax

        $sequence_1 = { 8b84248c000000 ffc8 8984248c000000 83bc248c00000007 0f875d010000 486384248c000000 }
            // n = 6, score = 200
            //   8b84248c000000       | mov                 eax, dword ptr [esp + 0x8c]
            //   ffc8                 | dec                 eax
            //   8984248c000000       | mov                 dword ptr [esp + 0x8c], eax
            //   83bc248c00000007     | cmp                 dword ptr [esp + 0x8c], 7
            //   0f875d010000         | ja                  0x163
            //   486384248c000000     | dec                 eax

        $sequence_2 = { 8b842490000000 25ff000000 488b4c2430 884101 }
            // n = 4, score = 200
            //   8b842490000000       | mov                 eax, dword ptr [esp + 0x90]
            //   25ff000000           | and                 eax, 0x200
            //   488b4c2430           | test                eax, eax
            //   884101               | je                  0x13

        $sequence_3 = { 8b84248c020000 8944244c 488b8c2420030000 e8???????? }
            // n = 4, score = 200
            //   8b84248c020000       | inc                 esp
            //   8944244c             | mov                 eax, eax
            //   488b8c2420030000     | mov                 edx, 0x5c
            //   e8????????           |                     

        $sequence_4 = { 8b842490000000 2500040000 85c0 740a c744245000000000 eb0a 8b442448 }
            // n = 7, score = 200
            //   8b842490000000       | test                eax, eax
            //   2500040000           | je                  0x13
            //   85c0                 | mov                 eax, dword ptr [esp + 0x90]
            //   740a                 | and                 eax, 0x200
            //   c744245000000000     | test                eax, eax
            //   eb0a                 | je                  0x13
            //   8b442448             | mov                 dword ptr [esp + 0x38], 0

        $sequence_5 = { 8b84248c020000 448bc0 ba5c000000 488d8c24f0010000 e8???????? }
            // n = 5, score = 200
            //   8b84248c020000       | lea                 edx, [esp + 0x1f0]
            //   448bc0               | dec                 eax
            //   ba5c000000           | lea                 ecx, [esp + 0x2a0]
            //   488d8c24f0010000     | mov                 eax, dword ptr [esp + 0x154]
            //   e8????????           |                     

        $sequence_6 = { 8b84248c020000 448bc0 488d9424f0010000 488d8c24a0020000 e8???????? }
            // n = 5, score = 200
            //   8b84248c020000       | inc                 eax
            //   448bc0               | mov                 eax, dword ptr [esp + 0x28c]
            //   488d9424f0010000     | inc                 esp
            //   488d8c24a0020000     | mov                 eax, eax
            //   e8????????           |                     

        $sequence_7 = { 8b842490000000 39442420 0f83e0000000 488d442438 41b808000000 488b542440 }
            // n = 6, score = 200
            //   8b842490000000       | je                  0x13
            //   39442420             | mov                 dword ptr [esp + 0x50], 0
            //   0f83e0000000         | jmp                 0x1d
            //   488d442438           | mov                 eax, dword ptr [esp + 0x48]
            //   41b808000000         | mov                 eax, dword ptr [esp + 0x90]
            //   488b542440           | and                 eax, 0xff

    condition:
        7 of them and filesize < 6703104
}